depends = ('ITKPyBase', 'ITKImageIntensity', )
templates = (
  ('BinaryContourImageFilter', 'itk::BinaryContourImageFilter', 'itkBinaryContourImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('BinaryContourImageFilter', 'itk::BinaryContourImageFilter', 'itkBinaryContourImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('BinaryContourImageFilter', 'itk::BinaryContourImageFilter', 'itkBinaryContourImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryContourImageFilter', 'itk::BinaryContourImageFilter', 'itkBinaryContourImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryContourImageFilter', 'itk::BinaryContourImageFilter', 'itkBinaryContourImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryContourImageFilter', 'itk::BinaryContourImageFilter', 'itkBinaryContourImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryContourImageFilter', 'itk::BinaryContourImageFilter', 'itkBinaryContourImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('BinaryContourImageFilter', 'itk::BinaryContourImageFilter', 'itkBinaryContourImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('ChangeLabelImageFilter', 'itk::ChangeLabelImageFilter', 'itkChangeLabelImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('ChangeLabelImageFilter', 'itk::ChangeLabelImageFilter', 'itkChangeLabelImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('ChangeLabelImageFilter', 'itk::ChangeLabelImageFilter', 'itkChangeLabelImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('ChangeLabelImageFilter', 'itk::ChangeLabelImageFilter', 'itkChangeLabelImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('ChangeLabelImageFilter', 'itk::ChangeLabelImageFilter', 'itkChangeLabelImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ChangeLabelImageFilter', 'itk::ChangeLabelImageFilter', 'itkChangeLabelImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('LabelContourImageFilter', 'itk::LabelContourImageFilter', 'itkLabelContourImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('LabelContourImageFilter', 'itk::LabelContourImageFilter', 'itkLabelContourImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('LabelContourImageFilter', 'itk::LabelContourImageFilter', 'itkLabelContourImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('LabelContourImageFilter', 'itk::LabelContourImageFilter', 'itkLabelContourImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('LabelContourImageFilter', 'itk::LabelContourImageFilter', 'itkLabelContourImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('LabelContourImageFilter', 'itk::LabelContourImageFilter', 'itkLabelContourImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('LabelContourImageFilter', 'itk::LabelContourImageFilter', 'itkLabelContourImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('LabelContourImageFilter', 'itk::LabelContourImageFilter', 'itkLabelContourImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonISS2IUL2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned long,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonISS3IUL3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned long,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonISS2IUC2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned char,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonISS3IUC3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned char,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonISS2IUS2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonISS3IUS3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUC2IUL2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned long,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUC3IUL3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned long,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUC2ISS2', True, 'itk::Image< unsigned char,2 >, itk::Image< signed short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUC3ISS3', True, 'itk::Image< unsigned char,3 >, itk::Image< signed short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUC2IUS2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUC3IUS3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUS2IUL2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned long,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUS3IUL3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned long,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUS2ISS2', True, 'itk::Image< unsigned short,2 >, itk::Image< signed short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUS3ISS3', True, 'itk::Image< unsigned short,3 >, itk::Image< signed short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUS2IUC2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUS3IUC3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF22ISS2', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< signed short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF23ISS3', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< signed short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF32ISS2', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< signed short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF33ISS3', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< signed short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF42ISS2', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< signed short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF43ISS3', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< signed short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF22IUC2', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< unsigned char,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF23IUC3', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< unsigned char,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF32IUC2', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< unsigned char,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF33IUC3', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< unsigned char,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF42IUC2', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< unsigned char,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF43IUC3', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< unsigned char,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF22IUS2', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< unsigned short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF23IUS3', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< unsigned short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF32IUS2', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< unsigned short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF33IUS3', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< unsigned short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF42IUS2', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< unsigned short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonIVF43IUS3', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< unsigned short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF22ISS2', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< signed short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF23ISS3', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< signed short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF32ISS2', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< signed short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF33ISS3', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< signed short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF42ISS2', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< signed short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF43ISS3', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< signed short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF22IUC2', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< unsigned char,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF23IUC3', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< unsigned char,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF32IUC2', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< unsigned char,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF33IUC3', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< unsigned char,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF42IUC2', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< unsigned char,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF43IUC3', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< unsigned char,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF22IUS2', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< unsigned short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF23IUS3', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< unsigned short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF32IUS2', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< unsigned short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF33IUS3', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< unsigned short,3 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF42IUS2', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< unsigned short,2 >'),
  ('ScanlineFilterCommon', 'itk::ScanlineFilterCommon', 'itkScanlineFilterCommonICVF43IUS3', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< unsigned short,3 >'),
)
snake_case_functions = ('label_contour_image_filter', 'change_label_image_filter', 'binary_contour_image_filter', 'unary_functor_image_filter', )
